@@ -14,7 +14,7 @@ class LightGBMEvalLogic(CommonBoostingEvalLogic):
         if self._n_eval_sets(model=model) == 1:
             return None
 
-        return 'training'
+        return "training"
 
     def _eval_metrics_key(self, model) -> str:
-        return 'valid_' + str(self._n_eval_sets(model=model) - 1)
+        return "valid_" + str(self._n_eval_sets(model=model) - 1)
